# sixl

## Installation

```
pip install sixl
```

## Examples

### Matplotlib

```python
%matplotlib inline
import sixl
from matplotlib import pyplot as plt

plt.plot([1,2,3], [1,4,9])
```

### Pillow

```python
import PIL.Image
img = PIL.Image.load("image.png")
```
